@@ -1,4 +1,4 @@
--- $Id: stored.sql 39795 2013-07-16 12:56:28Z wsl $
+-- $Id: stored.sql 41248 2014-03-31 11:56:32Z wsl $
 -- $URL: https://svn.uvt.nl/its-id/trunk/sources/kiki/doc/stored.sql $
 
 \encoding UTF8
@@ -428,7 +428,7 @@ CREATE OR REPLACE FUNCTION export_virtual() RETURNS TABLE (virt_from TEXT, virt_
 
 		FOR virt_from, virt_dest IN SELECT DISTINCT a.address, e.mailaddress
 			FROM virtual v
-			JOIN mail_addresses a ON a.mail_alias = v.mail_alias
+			JOIN all_mail_addresses a ON a.mail_alias = v.mail_alias
 			JOIN external_destinations e ON e.mail_alias = v.derived
 		LOOP
 			RETURN NEXT;
@@ -436,7 +436,7 @@ CREATE OR REPLACE FUNCTION export_virtual() RETURNS TABLE (virt_from TEXT, virt_
 
 		FOR virt_from, virt_dest IN SELECT DISTINCT a.address, p.mailaddress
 			FROM virtual v
-			JOIN mail_addresses a ON a.mail_alias = v.mail_alias
+			JOIN all_mail_addresses a ON a.mail_alias = v.mail_alias
 			JOIN personal_destinations dst ON dst.mail_alias = v.derived
 			JOIN persons p ON p.person = dst.person
 		LOOP
